#
# spec file for package libqt5-qttools
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define qt5_snapshot 0

Name:           libqt5-qttools
Version:        5.3.0
Release:        0
Summary:        Qt 5 QtTools Module
License:        SUSE-LGPL-2.1-with-digia-exception-1.1 or GPL-3.0
Group:          Development/Libraries/X11
Url:            http://qt.digia.com
%define base_name libqt5
%define real_version 5.3.0
%define so_version 5.3.0
%if %qt5_snapshot
%define tar_version qttools-%{real_version}
%else
%define tar_version qttools-opensource-src-%{real_version}
%endif
Source:         %{tar_version}.tar.xz
Source1:        baselibs.conf
Source11:       designer5.desktop
Source12:       linguist5.desktop
Source13:       assistant5.desktop
Source14:       assistant5.png
Source15:       designer5.png
Source16:       linguist5.png
BuildRequires:  fdupes
BuildRequires:  libQt5WebKitWidgets-devel >= %{version}
BuildRequires:  libqt5-qtbase-devel >= %{version}
BuildRequires:  libqt5-qtbase-private-headers-devel >= %{version}
BuildRequires:  libqt5-qtdeclarative-private-headers-devel >= %{version}
BuildRequires:  libxslt-devel
BuildRequires:  update-desktop-files
Recommends:     libqt5-linguist
%if %qt5_snapshot
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  xz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Qt is a set of libraries for developing applications.

This package contains base tools, like string, xml, and network handling.

%prep
%if %qt5_snapshot
%setup -q -n qttools-%{real_version}
%else
%setup -q -n qttools-opensource-src-%{real_version}
%endif

%package devel
Summary:        Qt Development Kit
Group:          Development/Libraries/X11
Requires:       %{name} = %{version}
Requires:       libQt5CLucene5 = %{version}
Requires:       libQt5Designer5 = %{version}
Requires:       libQt5DesignerComponents5 = %{version}
Requires:       libQt5Help5 = %{version}
Requires:       libqt5-linguist-devel = %{version}
Requires:       libxslt-devel

%description devel
You need this package, if you want to compile programs with qttools.

%package private-headers-devel
Summary:        Non-ABI stable experimental API
Group:          Development/Libraries/C and C++
BuildArch:      noarch
Requires:       %{name}-devel = %{version}

%description private-headers-devel
This package provides private headers of libqt5-qttools that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package examples
Summary:        Qt5 tools examples
Group:          Development/Libraries/X11
Recommends:     %{name}-devel

%description examples
Examples for libqt5-qttools module.

%package -n libQt5CLucene5
Summary:        Qt 5 Clucene Library
Group:          Development/Libraries/X11

%description -n libQt5CLucene5
The Qt 5 Clucene library.

%package -n libQt5Designer5
Summary:        Qt 5 Designer Library
Group:          Development/Libraries/X11

%description -n libQt5Designer5
The Qt 5 Designer library.

%package -n libQt5DesignerComponents5
Summary:        Qt 5 Designer Components Library
Group:          Development/Libraries/X11

%description -n libQt5DesignerComponents5
The Qt 5 Designer Components library.

%package -n libQt5Help5
Summary:        Qt 5 Help Library
Group:          Development/Libraries/X11

%description -n libQt5Help5
The Qt 5 Help library.

%package -n libqt5-linguist
Summary:        Qt 5 Linguist Tools
Group:          Development/Libraries/X11

%description -n libqt5-linguist
The Qt 5 Linguist Tools.

%package -n libqt5-linguist-devel
Summary:        Qt 5 Linguist Tools - development files
Group:          Development/Libraries/X11
Requires:       libqt5-linguist = %{version}
Requires:       pkgconfig(Qt5Core) >= %{version}

%description -n libqt5-linguist-devel
The Qt 5 Linguist Tools - development files.

%post -p /sbin/ldconfig

%post -n libQt5CLucene5 -p /sbin/ldconfig

%post -n libQt5Designer5 -p /sbin/ldconfig

%post -n libQt5DesignerComponents5 -p /sbin/ldconfig

%post -n libQt5Help5 -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%postun -n libQt5CLucene5 -p /sbin/ldconfig

%postun -n libQt5Designer5 -p /sbin/ldconfig

%postun -n libQt5DesignerComponents5 -p /sbin/ldconfig

%postun -n libQt5Help5 -p /sbin/ldconfig

%build
%if %qt5_snapshot
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%qmake5
%make_jobs

%install
%qmake5_install
find %{buildroot}/%{_libdir} -type f -name '*la' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} \;
find %{buildroot}/%{_libdir} -type f -name '*pc' -print -exec perl -pi -e "s, -L$RPM_BUILD_DIR/?\S+,,g" {} \; -exec sed -i -e "s,^moc_location=.*,moc_location=%{_libqt5_bindir}/moc," -e "s,uic_location=.*,uic_location=%{_libqt5_bindir}/uic," {} \;
%fdupes -s %{buildroot}/%{_libqt5_includedir}

# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

# put all the binaries to %_bindir, add -qt5 suffix, and symlink them back to %_qt5_bindir
mkdir -p %{buildroot}%{_bindir}
pushd %{buildroot}%{_libqt5_bindir}
for i in * ; do
  case "${i}" in
   assistant|designer|lconvert|linguist|lrelease|lupdate|pixeltool|qcollectiongenerator|qdbus|qdbusviewer|qhelpconverter|qhelpgenerator)
      mv $i ../../../bin/${i}-qt5
      ln -s ../../../bin/${i}-qt5 .
      ln -s ../../../bin/${i}-qt5 $i
      ;;
   *)
      mv $i ../../../bin/
      ln -s ../../../bin/$i .
      ;;
  esac
done
popd

#
# install menu entries
#

##%suse_update_desktop_file -i designer5  Qt Development GUIDesigner
##%suse_update_desktop_file -i linguist5  Qt Development Translation
##%suse_update_desktop_file -i assistant5 Qt Development Documentation

##mkdir -p %{buildroot}%{_datadir}/doc/packages/libqt5
##cp -a src/assistant/assistant/assistant.qch %{buildroot}%{_datadir}/doc/packages/libqt5/

%files
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.FDL LICENSE.GPL LICENSE.LGPL
%{_bindir}/assistant*
%{_bindir}/designer*
%{_bindir}/pixeltool*
%{_bindir}/qcollectiongenerator*
%{_bindir}/qdbus*
%{_bindir}/qdbusviewer*
%{_bindir}/qhelpconverter*
%{_bindir}/qhelpgenerator*
%{_bindir}/qtdiag*
%{_bindir}/qtpaths*
%{_libqt5_bindir}/assistant*
%{_libqt5_bindir}/designer*
%{_libqt5_bindir}/pixeltool*
%{_libqt5_bindir}/qcollectiongenerator*
%{_libqt5_bindir}/qdbus*
%{_libqt5_bindir}/qdbusviewer*
%{_libqt5_bindir}/qhelpconverter*
%{_libqt5_bindir}/qhelpgenerator*
%{_libqt5_bindir}/qtdiag*
%{_libqt5_bindir}/qtpaths*
%{_datadir}/applications/assistant5.desktop
%{_datadir}/applications/designer5.desktop
%{_datadir}/pixmaps/assistant5.png
%{_datadir}/pixmaps/designer5.png
%{_libqt5_libdir}/qt5/plugins/designer

%files -n libqt5-linguist
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.FDL LICENSE.GPL LICENSE.LGPL
%{_bindir}/lconvert*
%{_bindir}/linguist*
%{_bindir}/lrelease*
%{_bindir}/lupdate*
%{_libqt5_bindir}/lconvert*
%{_libqt5_bindir}/linguist*
%{_libqt5_bindir}/lrelease*
%{_libqt5_bindir}/lupdate*
%{_datadir}/applications/linguist5.desktop
%{_datadir}/pixmaps/linguist5.png

%files -n libQt5CLucene5
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.FDL LICENSE.GPL LICENSE.LGPL
%{_libqt5_libdir}/libQt5CLucene.so.*

%files -n libQt5Designer5
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.FDL LICENSE.GPL LICENSE.LGPL
%{_libqt5_libdir}/libQt5Designer.so.*

%files -n libQt5DesignerComponents5
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.FDL LICENSE.GPL LICENSE.LGPL
%{_libqt5_libdir}/libQt5DesignerComponents.so.*

%files -n libQt5Help5
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.FDL LICENSE.GPL LICENSE.LGPL
%{_libqt5_libdir}/libQt5Help.so.*

%files -n libqt5-linguist-devel
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.FDL LICENSE.GPL LICENSE.LGPL
%{_libqt5_libdir}/cmake/Qt5LinguistTools/
%{_datadir}/qt5/phrasebooks

%files private-headers-devel
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.FDL LICENSE.GPL LICENSE.LGPL
%{_libqt5_includedir}/QtCLucene/%{so_version}
%{_libqt5_includedir}/QtDesigner/%{so_version}
%{_libqt5_includedir}/QtDesignerComponents/%{so_version}
%{_libqt5_includedir}/QtHelp/%{so_version}
%{_libqt5_includedir}/QtUiTools/%{so_version}

%files devel
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.FDL LICENSE.GPL LICENSE.LGPL
%exclude %{_libqt5_includedir}/QtCLucene/%{so_version}
%{_libqt5_includedir}/QtCLucene
%exclude %{_libqt5_includedir}/QtDesigner/%{so_version}
%{_libqt5_includedir}/QtDesigner
%exclude %{_libqt5_includedir}/QtDesignerComponents/%{so_version}
%{_libqt5_includedir}/QtDesignerComponents
%exclude %{_libqt5_includedir}/QtHelp/%{so_version}
%{_libqt5_includedir}/QtHelp
%exclude %{_libqt5_includedir}/QtUiTools/%{so_version}
%{_libqt5_includedir}/QtUiTools
%{_libqt5_libdir}/cmake/Qt5Designer/
%{_libqt5_libdir}/cmake/Qt5Help/
%{_libqt5_libdir}/cmake/Qt5UiTools/
%{_libqt5_libdir}/libQt5*.prl
%{_libqt5_libdir}/libQt5*.so
%{_libqt5_libdir}/libQt5*.a
%{_libqt5_libdir}/pkgconfig/Qt5*.pc
%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_*.pri
%dir %{_datadir}/qt5

%files examples
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.FDL LICENSE.GPL LICENSE.LGPL
%{_libqt5_examplesdir}/

%changelog
